@@ -134,15 +134,24 @@ class Fqdn:
 
 
 @dataclass
-class IpAddress:
-    """
-
-    An IP address.
-    """
-
+class IpAddressType:
     class Meta:
-        name = "ip-address"
-        namespace = AI_1_1_NAMESPACE
+        name = "ip-address-type"
+
+    ip_v4: Optional["IpAddressType.IpV4"] = field(
+        default=None,
+        metadata={
+            "name": "ip-v4",
+            "type": "Element",
+        }
+    )
+    ip_v6: Optional["IpAddressType.IpV6"] = field(
+        default=None,
+        metadata={
+            "name": "ip-v6",
+            "type": "Element",
+        }
+    )
 
     @dataclass
     class IpV4:
@@ -204,22 +213,6 @@ class IpAddress:
             }
         )
 
-    ip_v4: Optional[IpV4] = field(
-        default=None,
-        metadata={
-            "name": "ip-v4",
-            "type": "Element",
-        }
-    )
-
-    ip_v6: Optional[IpV6] = field(
-        default=None,
-        metadata={
-            "name": "ip-v6",
-            "type": "Element",
-        }
-    )
-
 
 @dataclass
 class Location:
@@ -460,6 +453,17 @@ class WebsiteUrl:
     )
 
 
+@dataclass
+class IpAddress(IpAddressType):
+    """
+    An IP address.
+    """
+
+    class Meta:
+        name = "ip-address"
+        namespace = AI_1_1_NAMESPACE
+
+
 @dataclass
 class LocationAddress:
     """
@@ -1341,7 +1345,7 @@ class Locations:
 
 
 @dataclass
-class NetworkInterface:
+class NetworkInterfaceType:
     """
     :ivar ip_address: The IP address for this network interface.
     :ivar mac_address: The MAC address associated with this network
@@ -1364,27 +1368,27 @@ class NetworkInterface:
             "namespace": AI_1_1_NAMESPACE,
         }
     )
-    mac_address: Optional["NetworkInterface.MacAddress"] = field(
+    mac_address: Optional["NetworkInterfaceType.MacAddress"] = field(
         default=None,
         metadata={
             "name": "mac-address",
             "type": "Element",
         }
     )
-    url: List["NetworkInterface.Url"] = field(
+    url: List["NetworkInterfaceType.Url"] = field(
         default_factory=list,
         metadata={
             "type": "Element",
         }
     )
-    subnet_mask: Optional[IpAddress] = field(
+    subnet_mask: Optional[IpAddressType] = field(
         default=None,
         metadata={
             "name": "subnet-mask",
             "type": "Element",
         }
     )
-    default_route: Optional[IpAddress] = field(
+    default_route: Optional[IpAddressType] = field(
         default=None,
         metadata={
             "name": "default-route",
@@ -1776,7 +1780,7 @@ class ComputingDeviceType(ItAssetType):
         """
         :ivar connection: An IP network interface connection.
         """
-        connection: List[NetworkInterface] = field(
+        connection: List[NetworkInterfaceType] = field(
             default_factory=list,
             metadata={
                 "type": "Element",
@@ -1981,7 +1985,7 @@ class NetworkType(ItAssetType):
             network.
         :ivar ip_net_range_end: The ending IP address in the network.
         """
-        ip_net_range_start: Optional[IpAddress] = field(
+        ip_net_range_start: Optional[IpAddressType] = field(
             default=None,
             metadata={
                 "name": "ip-net-range-start",
@@ -1989,7 +1993,7 @@ class NetworkType(ItAssetType):
                 "required": True,
             }
         )
-        ip_net_range_end: Optional[IpAddress] = field(
+        ip_net_range_end: Optional[IpAddressType] = field(
             default=None,
             metadata={
                 "name": "ip-net-range-end",
