@@ -8,10 +8,11 @@ from .common import (
     MessageType,
     SimpleDatatypeEnumeration,
 )
-from .namespaces import OVAL_NAMESPACE_MAP
-from ..common.utils import scap_parser, scap_json_parser, scap_serializer, scap_json_serializer
+from ..common.utils import ParsableElement
 from ..common.xmldsig import Signature
 
+OVAL_SYSTEM_CHARACTERISTICS_5_NAMESPACE = "http://oval.mitre.org/XMLSchema/oval-system-characteristics-5"
+
 
 class EntityItemIpaddressStringTypeDatatype(Enum):
     """
@@ -1815,7 +1816,7 @@ class Item(ItemType):
 
     class Meta:
         name = "item"
-        namespace = "http://oval.mitre.org/XMLSchema/oval-system-characteristics-5"
+        namespace = OVAL_SYSTEM_CHARACTERISTICS_5_NAMESPACE
 
 
 @dataclass
@@ -1838,14 +1839,14 @@ class SystemDataType:
     #     default_factory=list,
     #     metadata={
     #         "type": "Element",
-    #         "namespace": "http://oval.mitre.org/XMLSchema/oval-system-characteristics-5",
+    #         "namespace": OVAL_SYSTEM_CHARACTERISTICS_5_NAMESPACE,
     #         "min_occurs": 1,
     #     }
     # )
 
 
 @dataclass
-class OvalSystemCharacteristics:
+class OvalSystemCharacteristics(ParsableElement):
     """The system_characteristics element is the root of an OVAL System
     Characteristics Document, and must occur exactly once.
 
@@ -1874,7 +1875,7 @@ class OvalSystemCharacteristics:
 
     class Meta:
         name = "oval_system_characteristics"
-        namespace = "http://oval.mitre.org/XMLSchema/oval-system-characteristics-5"
+        namespace = OVAL_SYSTEM_CHARACTERISTICS_5_NAMESPACE
 
     generator: Optional[GeneratorType] = field(
         default=None,
@@ -1910,23 +1911,3 @@ class OvalSystemCharacteristics:
             "namespace": "http://www.w3.org/2000/09/xmldsig#",
         }
     )
-
-    @classmethod
-    def load(cls, file):
-        with open(file, "rb") as fp:
-            system_characteristics = scap_parser.parse(fp, cls)
-        return system_characteristics
-
-    @classmethod
-    def load_json(cls, file):
-        with open(file, "rb") as fp:
-            system_characteristics = scap_json_parser.parse(fp, cls)
-        return system_characteristics
-
-    def dump(self, file):
-        with open(file, "w", encoding="utf8") as fp:
-            scap_serializer.write(fp, self, ns_map=OVAL_NAMESPACE_MAP)
-
-    def dump_json(self, file):
-        with open(file, "w", encoding="utf8") as fp:
-            scap_json_serializer.write(fp, self)
